@@ -120,12 +120,16 @@ class OAuthTwitterTest(TestCase):
         settings.LOGIN_REDIRECT_URLNAME = self.old_login_redirect_urlname
 
     def test_association_anonymous(self):
+        import django
         # Ensure we need a login.
         url = reverse('twitter_associate')
+        login_url = settings.LOGIN_URL
+        if django.VERSION < (1, 2):
+            login_url = self.old_login_url
         response = self.client.get(url)
         self.assertEqual(
             response['Location'],
-            'http://testserver%s?next=%s' % (self.old_login_url,
+            'http://testserver%s?next=%s' % (login_url,
                                              quote('http://testserver' + url))
         )
 
