@@ -11,6 +11,13 @@ from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 
+try:
+    from django.utils.decorators import method_decorator
+except ImportError:
+    login_required_m = login_required
+else:
+    login_required_m = method_decorator(login_required)
+
 from django_oauth_twitter.forms import RegistrationForm
 from django_oauth_twitter.middleware import (cached_user_info,
                                              get_success_url,
@@ -91,7 +98,7 @@ class OAuthTwitter(object):
         return urlpatterns
     urls = property(get_urls)
 
-    @login_required
+    @login_required_m
     def associate(self, request,
                   template="django_oauth_twitter/associate.html",
                   dictionary=None):
